@@ -5,8 +5,7 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 //
 
-#ifndef INCLUDED_UHD_VERSION_HPP
-#define INCLUDED_UHD_VERSION_HPP
+#pragma once
 
 /*!
  * The ABI version string that the client application builds against.
@@ -14,14 +13,14 @@
  * The format is oldest API compatible release - ABI compat number.
  * The compatibility number allows pre-release ABI to be versioned.
  */
-#define UHD_VERSION_ABI_STRING "3.11.1"
+#define UHD_VERSION_ABI_STRING "4.2.0"
 
 /*!
  * A macro to check UHD version at compile-time.
  * The value of this macro is MAJOR * 1000000 + API * 10000 + ABI * 100 + PATCH
  * (e.g., for UHD 3.10.0.1 this is 3100001).
  */
-#define UHD_VERSION 3110100
+#define UHD_VERSION 4020000
 
 #ifdef __cplusplus
 #include <uhd/config.hpp>
@@ -35,7 +34,8 @@ namespace uhd{
     //! Get the ABI compatibility string for this build of the library
     UHD_API std::string get_abi_string(void);
 
+    //! Get the component string
+    UHD_API std::string get_component(void);
+
 } //namespace uhd
 #endif
-
-#endif /* INCLUDED_UHD_VERSION_HPP */
